@@ -17,6 +17,8 @@ function niceback_show(id) {
 }
 """
 
+local_urls = False
+
 
 def html_traceback(exc=None, chain=None, **extract_args):
     chain = chain or extract_chain(exc=exc, **extract_args)[-3:]
@@ -49,11 +51,14 @@ def _exception(doc, info):
     if not frames:
         return
     # Format call chain
-    limitedframes = frames[:16]
+    limitedframes = [*frames[:10], ..., *frames[-4:]] if len(frames) > 16 else frames
     with doc.div(class_="traceback-tabs"):
         if len(limitedframes) > 1:
             with doc.div(class_="traceback-labels"):
                 for info in limitedframes:
+                    if info is ...:
+                        doc("...")
+                        continue
                     doc.button(
                         E.strong(info["location"]).br.small(
                             info["function"] or "－"),
@@ -61,14 +66,15 @@ def _exception(doc, info):
                     )
         with doc.div(class_="content"):
             for info in limitedframes:
+                if info is ...:
+                    with doc.div(class_="traceback-details"):
+                        doc.p("...")
+                    continue
                 with doc.div(class_="traceback-details", id=info['id']):
-                    doc.span(
-                        style="font-size: 2em",
-                    )
                     if info['filename']:
                         doc.p.b(f"{info['filename']}")(f":{info['lineno']}")
                         urls = info["urls"]
-                        if urls:
+                        if local_urls and urls:
                             for name, href in urls.items():
                                 doc(" ").a(name, href=href)
                     else:
